#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"


void
on_okbutton1_released                  (GtkButton       *button,
                                        gpointer         user_data)
{
    system("killall matchbox-panel 2>/dev/null || killall openbox 2>/dev/null");
}
